@@ -14,4 +14,4 @@ def test_dummy():
     c0 : Term = concepts[0]
     assert c0.identifier == 'test'
     assert c0.preferredForm == 'test'
-    assert c0.properties is None
+    assert c0.properties['altForms'] == ['TEST']
